@@ -1,6 +1,6 @@
 #!/usr/bin/python3
 # 
-# (c) mmxxii shinobi
+# (c) mmxxii nobody
 #
 # when using as bbs doors set TERM to linux:
 #
@@ -48,7 +48,7 @@ def get_env_var(p_var):
 # print the sauce information
 def prn_help():
   global prn_cy
-  prn_cy = 3
+  prn_cy = 1
   #cols = str(int.from_bytes(pos_sauce[96:98],"little"))
   #rows = (int.from_bytes(pos_sauce[98:100],"little"))
   prn(r" __________                               ")
@@ -63,6 +63,7 @@ def prn_help():
   prn(r"")
   prn(r"   u, n       - scroll up, down more         ")
   prn(r"   k, j, h, l - scroll up, down, left, right ")
+  prn(r"   0,G        - goto begin, end of file      ")
   prn(r"   $          - display sauce information    ")
   prn(r"   ?          - display help                 ")
   prn(r"   a          - autoscroll                   ")
@@ -151,7 +152,6 @@ def render_ans(pad, ans, width=80, height=25, shift_y=0):
   # display ans variables
   cx = 0
   cy = 0
-  # previous char is 0x0d
   # escape sequence state
   stat = ""
   attr = ""
@@ -163,12 +163,8 @@ def render_ans(pad, ans, width=80, height=25, shift_y=0):
   # init base color
   if curcol not in clrs:
     init_cur_clr(fgcol,bgcol,inten)
-  is0d = 0
   # main ansi loop
   for c in ans:
-    # from this point there could be SAUCE
-    #if c == 0x1a:
-    #  break
     # new line move to new line
     if c == ord("\n"): # 0x0a
       cy += 1
@@ -212,8 +208,18 @@ def render_ans(pad, ans, width=80, height=25, shift_y=0):
         # hight intensity attribute
         elif ia == 1:
           inten = "hi" 
+        # default foreground color
+        elif (ia == 39):
+          inten = "lo"
+          fgcol = "Wh"
+        # default background color
+        elif (ia == 49):
+          inten = "me"
+          bgcol = "Bk"
         # foreground colors
         elif (ia >= 30 and ia <= 37) or (ia >= 90 and ia <= 97):
+          if (ia >= 90 and ia <= 97):
+            inten = "hi" 
           fgcol = get_col(ia)
         # background colors
         elif (ia >= 40 and ia <= 47) or (ia >= 100 and ia <= 107):
@@ -283,7 +289,7 @@ def main():
   if len(sys.argv) == 1:
     print("Usage : pyans [OPTION...] <ansi file>")
     print("")
-    print("Python ANSI Console Browser 0.1.4")
+    print("Python ANSI Console Browser 0.1.5")
     print("Mandatory arguments:")
     print(" -a, --autoscroll  - autoscroll file and exit ")
     print("")
@@ -379,7 +385,7 @@ def main():
         shift_y = cli - he
     # scroll down
     elif k == ord("j"):
-      if shift_y < cli - he -1:
+      if shift_y < cli - he - 1:
         shift_y += 1
     # scroll up
     elif k == ord("k"):
@@ -391,19 +397,19 @@ def main():
         shift_x -= 1
     # scroll right
     elif k == ord("l"):
-      if shift_x < wi-1:
+      if shift_x < cols-1:
         shift_x += 1
     # display basic sauce information
     elif k == ord("$"):
       #cls(he)
-      #scr.clear()
+      scr.erase()
       prn_sauce_info(pos_sauce)
       scr.refresh()
       scr.getch()
     # display help
     elif k == ord("?"):
       #cls(he)
-      #scr.clear()
+      scr.erase()
       prn_help()
       scr.refresh()
       scr.getch()
